@@ -14,7 +14,12 @@
 #include <QDBusReply>
 #include <QProcess>
 #include <QUrl>
+
+#if QT_VERSION_MAJOR < 6
 #include <QX11Info>
+#else
+#include <QtGui/private/qtx11extras_p.h>
+#endif
 
 #include <KConfig>
 #include <KConfigGroup>
