@@ -16,7 +16,6 @@
 
 class QComboBox;
 class QLineEdit;
-class Ui_advancedTabOptions;
 class QVBoxLayout;
 class KMessageWidget;
 class QCheckBox;
@@ -26,12 +25,17 @@ class KKonqGeneralOptions : public KCModule
     Q_OBJECT
 
 public:
-    KKonqGeneralOptions(QWidget *parent, const QVariantList &);
+    //TODO KF6: when dropping compatibility with KF5, remove QVariantList argument
+    KKonqGeneralOptions(QObject *parent, const KPluginMetaData &md={}, const QVariantList &args={});
     ~KKonqGeneralOptions() override;
     void load() override;
     void save() override;
     void defaults() override;
 
+#if QT_VERSION_MAJOR < 6
+    void setNeedsSave(bool needs) {emit changed(needs);}
+#endif
+
 private Q_SLOTS:
     void slotChanged();
     void displayEmpytStartPageWarningIfNeeded();
@@ -48,8 +52,6 @@ private:
     QComboBox *m_splitBehaviour;
     KMessageWidget *m_emptyStartUrlWarning;
     QCheckBox *m_restoreLastState;
-
-    Ui_advancedTabOptions *tabOptions;
 };
 
 #endif // GENERALOPTS_H
