@@ -145,16 +145,16 @@ public:
     void setView(KonqView *view);
     bool isAsync() const {return m_isAsync;}
     void setOldLocationBarUrl(const QString &old);
-    QString oldLocationBarUrl() const {return m_oldLocationBarUrl;}
+    // QString oldLocationBarUrl() const {return m_oldLocationBarUrl;}
     bool hasError() const {return m_jobErrorCode;}
     void setNewTab(bool newTab);
 
-    /**
-     * @brief whether a given mimetype refers to an executable program instead of a data file
-     * @param mimeTypeName the mimetype to test
-     * @return `true` if @p mimeTypeName refers to an executable and `false` otherwise
-     */
-    static bool isExecutable(const QString &mimeTypeName);
+    // /**
+    //  * @brief whether a given mimetype refers to an executable program instead of a data file
+    //  * @param mimeTypeName the mimetype to test
+    //  * @return `true` if @p mimeTypeName refers to an executable and `false` otherwise
+    //  */
+    // static bool isExecutable(const QString &mimeTypeName);
     QString suggestedFileName() const {return m_request.suggestedFileName;}
 
     /**
@@ -180,7 +180,7 @@ private slots:
      *
      * @param job the DownloaderJob used by the part to download the URL
      */
-    void downloadForEmbeddingOrOpeningDone(KJob *job);
+    void downloadForEmbeddingOrOpeningDone(KonqInterfaces::DownloaderJob *job, const QUrl &url);
 
 private:
 
@@ -207,6 +207,18 @@ private:
     void decideAction();
     bool isViewLocked() const;
 
+    /**
+     * @brief Whether the URL we are loading is executable
+     *
+     * To be executable, all the following must be true:
+     * - the URL must be local (we don't want to execute files from the web)
+     * - the mimetype should be in a list of known executable types (desktop files, executable files, libraries,
+     *  shell scripts)
+     * - the executable bit must be set
+     * @return `true` if the file is executable and `false` otherwise
+     */
+    bool isUrlExecutable() const;
+
     /**
      * @brief Checks whether a file downloaded by a part really has the mime type described by the HTML header
      *
@@ -352,7 +364,29 @@ private:
     bool m_dontPassToWebEnginePart;
     bool m_protocolAllowsReading;
     bool m_letRequestingPartDownloadUrl = false; ///<Whether the URL should be downloaded by the part before opening/embedding/saving it
-    bool m_forceSave; ///<Whether the part explicitly asked for the URL to be saved
+    /**
+     * @brief Whether only the `embed` action is allowed
+     *
+     * If `true`, the only action performed will be to embed the URL. If that action can't be performed for any reason (including
+     * not having an available part able to display the URL or an error happening), nothing will be done (including displaying error messages).
+     *
+     * This variable is set if the metadata in the `KonqOpenURLRequest` passed to the constructor contains the `"EmbedOrNothing"` entry.
+     *
+     * @note This is a workaround to allow WebEnginePart to display a downloaded file without risking asking again the user to save
+     *
+     * @todo Remove this after a better way to allow the user to quickly display a file after downloading it has been implemented. See comment
+     * for WebEnginePage::saveUrlToDiskAndDisplay
+     */
+    bool m_embedOrNothing = false;
+
+    /**
+     * @brief The URL that the UrlLoader has been asked to open, in case the requesting parts wants to download it itself
+     *
+     * If the requesting part doesn't want to download the URL itself, this is empty. Otherwise, when the UrlLoader is created,
+     * this is the same as #m_url. After the part has finished downloading the URL, #m_url will contain the temporary local file
+     * the URL has been downloaded to, while #m_originalUrl will not be changed
+     */
+    QUrl m_originalUrl;
 };
 
 QDebug operator<<(QDebug dbg, UrlLoader::OpenUrlAction action);
